aboutsummaryrefslogtreecommitdiff
path: root/bpkg/package-skeleton.hxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2022-06-06 11:40:50 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2022-06-09 12:32:36 +0200
commitf0f5af955fe03fa120b69c39f4a23ff3a177769b (patch)
tree29b614333ec7c32d13290a992a30fe07e948f464 /bpkg/package-skeleton.hxx
parentb07c40f8a457bbb8f7f2d4d142e5e5e974465e25 (diff)
Implementation of evaluate_require() plus other tweaks
Diffstat (limited to 'bpkg/package-skeleton.hxx')
-rw-r--r--bpkg/package-skeleton.hxx9
1 files changed, 6 insertions, 3 deletions
diff --git a/bpkg/package-skeleton.hxx b/bpkg/package-skeleton.hxx
index 1c4ae32..e949784 100644
--- a/bpkg/package-skeleton.hxx
+++ b/bpkg/package-skeleton.hxx
@@ -178,11 +178,14 @@ namespace bpkg
//
// Call this function before evaluating every clause.
//
// If dependency configurations are specified, then set their values and
// save the resulting versions in config_variable_value::version.
//
build2::scope&
- load (const dependency_configurations& = {});
+ load (const dependency_configurations& = {}, bool defaults = true);
// Merge command line variable overrides into one list (normally to be
// passed to bootstrap()).
@@ -178,11 +178,14 @@ namespace bpkg
// Call this function before evaluating every clause.
//
- // If dependency configurations are specified, then set their values and
- // save the resulting versions in config_variable_value::version.
+ // If dependency configurations are specified, then typify the variables
+ // and set their values saving the resulting value versions in
+ // config_variable_value::version. If defaults is false, then only typify
+ // the variables and set overrides without setting the default/buildfile
+ // values.
//
build2::scope&